SignalCode

Enum SignalCode 

#[repr(u8)]
pub enum SignalCode { Execution(SimpleExecutionError), RemovedFromWaitlist, }
Enum representing signal code and reason of its creation.

Testing

See this document.

Variants



Execution(SimpleExecutionError)

Signal was sent due to some execution errors.



RemovedFromWaitlist

Signal was sent due to removal from waitlist as out of rent.

Implementations

Source

impl SignalCode

pub const fn to_u32(self) -> u32

Converts SignalCode into u32.

pub const fn from_u32(num: u32) -> Option<SignalCode>

Parses SignalCode from u32 if possible.