Send

Trait Send 

1.0.0 · Source
pub unsafe auto trait Send { }
Types that can be transferred across thread boundaries.

This trait is automatically implemented when the compiler determines it’s appropriate.

An example of a non-Send type is the reference-counting pointer rc::Rc. If two threads attempt to clone Rcs that point to the same reference-counted value, they might try to update the reference count at the same time, which is undefined behavior because Rc doesn’t use atomic operations. Its cousin sync::Arc does use atomic operations (incurring some overhead) and thus is Send.

See the Nomicon and the Sync trait for more details.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

1.0.0 · Source

impl !Send for Arguments<'_>

Source

impl !Send for LocalWaker

Source

impl Send for AtomicWaker

Source

impl Send for gstd::prelude::ffi::c_str::Bytes<'_>

1.6.0 · Source

impl Send for gstd::prelude::string::Drain<'_>

1.10.0 · Source

impl Send for Location<'_>

1.0.0 · Source

impl Send for TypeId

1.36.0 · Source

impl Send for Waker

Source

impl<'a, 'b, K, Q, V, S, A> Send for OccupiedEntryRef<'a, 'b, K, Q, V, S, A>
where K: Send, Q: Sync + ?Sized, V: Send, S: Send, A: Send + Allocator,

Source

impl<'a, T, const CAP: usize> Send for arrayvec::arrayvec::Drain<'a, T, CAP>
where T: Send,

Source

impl<'a, T> Send for smallvec::Drain<'a, T>
where T: Send + Array,

1.44.0 · Source

impl<'a> Send for IoSlice<'a>

1.44.0 · Source

impl<'a> Send for IoSliceMut<'a>

Source

impl<A> Send for SmallVec<A>
where A: Array, <A as Array>::Item: Send,

Source

impl<Dyn> Send for DynMetadata<Dyn>
where Dyn: ?Sized,

Source

impl<Fut> Send for FuturesUnordered<Fut>
where Fut: Send,

Source

impl<Fut> Send for futures_util::stream::futures_unordered::iter::IntoIter<Fut>
where Fut: Send + Unpin,

Source

impl<Fut> Send for IterPinMut<'_, Fut>
where Fut: Send,

Source

impl<Fut> Send for IterPinRef<'_, Fut>
where Fut: Send,

Source

impl<K, V, S, A> Send for gstd::prelude::collections::hash_map::OccupiedEntry<'_, K, V, S, A>
where K: Send, V: Send, S: Send, A: Send + Allocator,

Source

impl<K, V, S, A> Send for RawOccupiedEntryMut<'_, K, V, S, A>
where K: Send, V: Send, S: Send, A: Send + Allocator,

Source

impl<K, V> Send for gstd::prelude::collections::hash_map::IterMut<'_, K, V>
where K: Send, V: Send,

1.0.0 · Source

impl<T, A> !Send for Rc<T, A>
where A: Allocator, T: ?Sized,

Source

impl<T, A> !Send for UniqueRc<T, A>
where A: Allocator, T: ?Sized,

1.4.0 · Source

impl<T, A> !Send for gstd::prelude::rc::Weak<T, A>
where A: Allocator, T: ?Sized,

1.0.0 · Source

impl<T, A> Send for Arc<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Send + Sync,

Source

impl<T, A> Send for allocator_api2::stable::boxed::Box<T, A>
where A: Allocator + Send, T: Send + ?Sized,

Source

impl<T, A> Send for gstd::prelude::collections::linked_list::Cursor<'_, T, A>
where T: Sync, A: Allocator + Sync,

Source

impl<T, A> Send for gstd::prelude::collections::linked_list::CursorMut<'_, T, A>
where T: Send, A: Allocator + Send,

1.6.0 · Source

impl<T, A> Send for gstd::prelude::collections::vec_deque::Drain<'_, T, A>
where T: Send, A: Allocator + Send,

1.6.0 · Source

impl<T, A> Send for gstd::prelude::vec::Drain<'_, T, A>
where T: Send, A: Send + Allocator,

Source

impl<T, A> Send for allocator_api2::stable::vec::drain::Drain<'_, T, A>
where T: Send, A: Send + Allocator,

1.0.0 · Source

impl<T, A> Send for gstd::prelude::vec::IntoIter<T, A>
where T: Send, A: Allocator + Send,

Source

impl<T, A> Send for allocator_api2::stable::vec::into_iter::IntoIter<T, A>
where T: Send, A: Allocator + Send,

1.0.0 · Source

impl<T, A> Send for LinkedList<T, A>
where T: Send, A: Allocator + Send,

Source

impl<T, A> Send for hashbrown::table::OccupiedEntry<'_, T, A>
where T: Send, A: Send + Allocator,

Source

impl<T, A> Send for UniqueArc<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Send + Sync,

1.4.0 · Source

impl<T, A> Send for alloc::sync::Weak<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Send + Sync,

Source

impl<T, N> Send for GenericArray<T, N>
where T: Send, N: ArrayLength<T>,

1.0.0 · Source

impl<T> !Send for *const T
where T: ?Sized,

1.0.0 · Source

impl<T> !Send for *mut T
where T: ?Sized,

1.25.0 · Source

impl<T> !Send for NonNull<T>
where T: ?Sized,

NonNull pointers are not Send because the data they reference may be aliased.

1.0.0 · Source

impl<T> Send for &T
where T: Sync + ?Sized,

1.0.0 · Source

impl<T> Send for Atomic<T>
where T: AtomicPrimitive,

1.0.0 · Source

impl<T> Send for Cell<T>
where T: Send + ?Sized,

1.31.0 · Source

impl<T> Send for ChunksExactMut<'_, T>
where T: Send,

1.0.0 · Source

impl<T> Send for ChunksMut<'_, T>
where T: Send,

Source

impl<T> Send for FutureObj<'_, T>

1.0.0 · Source

impl<T> Send for gstd::prelude::slice::Iter<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Send for gstd::prelude::collections::linked_list::Iter<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Send for gstd::prelude::slice::IterMut<'_, T>
where T: Send,

1.0.0 · Source

impl<T> Send for gstd::prelude::collections::linked_list::IterMut<'_, T>
where T: Send,

1.28.0 · Source

impl<T> Send for NonZero<T>

1.31.0 · Source

impl<T> Send for RChunksExactMut<'_, T>
where T: Send,

1.31.0 · Source

impl<T> Send for RChunksMut<'_, T>
where T: Send,

1.0.0 · Source

impl<T> Send for RefCell<T>
where T: Send + ?Sized,

Source

impl<T> Send for ThinBox<T>
where T: Send + ?Sized,

ThinBox<T> is Send if T is Send because the data is owned.

Auto implementors



impl !Send for RawWaker



impl Send for Abi



impl Send for ActorId



impl Send for gstd::prelude::fmt::Alignment



impl Send for gstd::prelude::mem::Alignment



impl Send for AsciiChar



impl Send for Assume



impl Send for BorrowError



impl Send for BorrowMutError



impl Send for CStr



impl Send for CString



impl Send for CharCase



impl Send for CharTryFromError



impl Send for CodeId



impl Send for Config



impl Send for Const



impl Send for ConversionError



impl Send for CreateProgramFuture



impl Send for DebugAsHex



impl Send for DecodeUtf16Error



impl Send for Duration



impl Send for DynTrait



impl Send for DynTraitPredicate



impl Send for EnvVars



impl Send for gstd::errors::CoreError



impl Send for gstd::errors::CodecError



impl Send for gstd::errors::Error



impl Send for gstd::prelude::fmt::Error



impl Send for ErrorReplyPayload



impl Send for ErrorReplyReason



impl Send for gstd::prelude::char::EscapeDebug



impl Send for gstd::prelude::ascii::EscapeDefault



impl Send for gstd::prelude::char::EscapeDefault



impl Send for gstd::prelude::char::EscapeUnicode



impl Send for ExecutionError



impl Send for ExtError



impl Send for FieldId



impl Send for FnPtr



impl Send for FormattingOptions



impl Send for FpCategory



impl Send for FromBytesUntilNulError



impl Send for FromBytesWithNulError



impl Send for FromUtf8Error



impl Send for FromUtf16Error



impl Send for FromVecWithNulError



impl Send for GasMultiplier



impl Send for Generic



impl Send for GenericType



impl Send for GetDisjointMutError



impl Send for IntErrorKind



impl Send for IntoChars



impl Send for IntoStringError



impl Send for Lifetime



impl Send for Locality



impl Send for MemoryError



impl Send for MessageError



impl Send for MessageFuture



impl Send for MessageHandle



impl Send for MessageId



impl Send for MetaType



impl Send for NulError



impl Send for OneSidedRangeBound



impl Send for Ordering



impl Send for ParseBoolError



impl Send for ParseCharError



impl Send for ParseFloatError



impl Send for ParseIntError



impl Send for Percent



impl Send for PhantomPinned



impl Send for ProgramGenerator



impl Send for RangeFull



impl Send for RawWakerVTable



impl Send for ReplyCode



impl Send for Reservation



impl Send for ReservationError



impl Send for ReservationId



impl Send for Reservations



impl Send for SearchStep



impl Send for Sign



impl Send for SignalCode



impl Send for SimpleExecutionError



impl Send for SimpleUnavailableActorError



impl Send for SipHasher



impl Send for Ss58Address



impl Send for Str



impl Send for String



impl Send for SuccessReplyReason



impl Send for SyscallError



impl Send for ToCasefold



impl Send for ToLowercase



impl Send for ToTitlecase



impl Send for ToUppercase



impl Send for Trait



impl Send for TryFromCharError



impl Send for TryFromFloatSecsError



impl Send for TryFromIntError



impl Send for TryFromSliceError



impl Send for gstd::prelude::collections::hashbrown::TryReserveError



impl Send for gstd::prelude::collections::TryReserveError



impl Send for TryReserveErrorKind



impl Send for Type



impl Send for TypeKind



impl Send for UnorderedKeyError



impl Send for UsageError



impl Send for Utf8Error



impl Send for VariantId



impl Send for c_void



impl<'a, 'b, K, Q, V, S, A> Send for EntryRef<'a, 'b, K, Q, V, S, A>
where OccupiedEntryRef<'a, 'b, K, Q, V, S, A>: Send, VacantEntryRef<'a, 'b, K, Q, V, S, A>: Send, Q: ?Sized,



impl<'a, 'b, K, Q, V, S, A> Send for VacantEntryRef<'a, 'b, K, Q, V, S, A>
where KeyOrRef<'b, K, Q>: Send, &'a mut HashMap<K, V, S, A>: Send, Q: ?Sized,



impl<'a, 'b, const N: usize> Send for CharArrayRefSearcher<'a, 'b, N>
where <MultiCharEqPattern<&'b [char; N]> as Pattern>::Searcher<'a>: Send,



impl<'a, 'b> !Send for DebugList<'a, 'b>



impl<'a, 'b> !Send for DebugMap<'a, 'b>



impl<'a, 'b> !Send for DebugSet<'a, 'b>



impl<'a, 'b> !Send for DebugStruct<'a, 'b>



impl<'a, 'b> !Send for DebugTuple<'a, 'b>



impl<'a, 'b> Send for CharSliceSearcher<'a, 'b>



impl<'a, 'b> Send for StrSearcher<'a, 'b>



impl<'a, A> Send for gstd::prelude::option::Iter<'a, A>
where Item<&'a A>: Send,



impl<'a, A> Send for gstd::prelude::option::IterMut<'a, A>
where Item<&'a mut A>: Send,



impl<'a, B> Send for Cow<'a, B>
where &'a B: Send, <B as ToOwned>::Owned: Send, B: ?Sized,



impl<'a, F> Send for CharPredicateSearcher<'a, F>
where <MultiCharEqPattern<F> as Pattern>::Searcher<'a>: Send,



impl<'a, I, A> Send for gstd::prelude::collections::vec_deque::Splice<'a, I, A>
where Drain<'a, <I as Iterator>::Item, A>: Send, I: Send,



impl<'a, I, A> Send for gstd::prelude::vec::Splice<'a, I, A>
where Drain<'a, <I as Iterator>::Item, A>: Send, I: Send,



impl<'a, I> Send for ByRefSized<'a, I>
where &'a mut I: Send,



impl<'a, K, A> Send for gstd::prelude::collections::btree_set::CursorMut<'a, K, A>
where CursorMut<'a, K, SetValZST, A>: Send,



impl<'a, K, A> Send for gstd::prelude::collections::btree_set::CursorMutKey<'a, K, A>
where CursorMutKey<'a, K, SetValZST, A>: Send,



impl<'a, K, A> Send for gstd::prelude::collections::hash_set::Drain<'a, K, A>
where Drain<'a, K, (), A>: Send,



impl<'a, K, F, A> Send for gstd::prelude::collections::hash_set::ExtractIf<'a, K, F, A>
where F: Send, RawExtractIf<'a, (K, ()), A>: Send,



impl<'a, K, V, A> Send for gstd::prelude::collections::btree_map::CursorMut<'a, K, V, A>
where CursorMutKey<'a, K, V, A>: Send,



impl<'a, K, V, A> Send for gstd::prelude::collections::btree_map::CursorMutKey<'a, K, V, A>
where Option<Handle<NodeRef<Mut<'a>, K, V, Leaf>, Edge>>: Send, DormantMutRef<'a, Option<NodeRef<Owned, K, V, LeafOrInternal>>>: Send, &'a mut A: Send,



impl<'a, K, V, A> Send for gstd::prelude::collections::hash_map::Drain<'a, K, V, A>
where RawDrain<'a, (K, V), A>: Send,



impl<'a, K, V, A> Send for gstd::prelude::collections::btree_map::Entry<'a, K, V, A>
where VacantEntry<'a, K, V, A>: Send, OccupiedEntry<'a, K, V, A>: Send,



impl<'a, K, V, A> Send for gstd::prelude::collections::btree_map::OccupiedEntry<'a, K, V, A>
where Handle<NodeRef<Mut<'a>, K, V, LeafOrInternal>, KV>: Send, DormantMutRef<'a, BTreeMap<K, V, A>>: Send, A: Send, PhantomData<&'a mut (K, V)>: Send,



impl<'a, K, V, A> Send for gstd::prelude::collections::btree_map::OccupiedError<'a, K, V, A>
where OccupiedEntry<'a, K, V, A>: Send, K: Send, V: Send,



impl<'a, K, V, A> Send for gstd::prelude::collections::btree_map::VacantEntry<'a, K, V, A>
where K: Send, Option<Handle<NodeRef<Mut<'a>, K, V, Leaf>, Edge>>: Send, DormantMutRef<'a, BTreeMap<K, V, A>>: Send, A: Send, PhantomData<&'a mut (K, V)>: Send,



impl<'a, K, V, F, A> Send for gstd::prelude::collections::hash_map::ExtractIf<'a, K, V, F, A>
where F: Send, RawExtractIf<'a, (K, V), A>: Send,



impl<'a, K, V, R, F, A> Send for gstd::prelude::collections::btree_map::ExtractIf<'a, K, V, R, F, A>
where F: Send, ExtractIfInner<'a, K, V, R>: Send, A: Send,



impl<'a, K, V, S, A> Send for gstd::prelude::collections::hash_map::Entry<'a, K, V, S, A>
where OccupiedEntry<'a, K, V, S, A>: Send, VacantEntry<'a, K, V, S, A>: Send,



impl<'a, K, V, S, A> Send for gstd::prelude::collections::hash_map::OccupiedError<'a, K, V, S, A>
where OccupiedEntry<'a, K, V, S, A>: Send, V: Send,



impl<'a, K, V, S, A> Send for RawEntryBuilder<'a, K, V, S, A>
where &'a HashMap<K, V, S, A>: Send,



impl<'a, K, V, S, A> Send for RawEntryBuilderMut<'a, K, V, S, A>
where &'a mut HashMap<K, V, S, A>: Send,



impl<'a, K, V, S, A> Send for RawEntryMut<'a, K, V, S, A>
where RawOccupiedEntryMut<'a, K, V, S, A>: Send, RawVacantEntryMut<'a, K, V, S, A>: Send,



impl<'a, K, V, S, A> Send for RawVacantEntryMut<'a, K, V, S, A>
where &'a mut RawTable<(K, V), A>: Send, &'a S: Send,



impl<'a, K, V, S, A> Send for gstd::prelude::collections::hash_map::VacantEntry<'a, K, V, S, A>
where K: Send, &'a mut HashMap<K, V, S, A>: Send,



impl<'a, K, V> Send for gstd::prelude::collections::btree_map::Cursor<'a, K, V>
where Option<Handle<NodeRef<Immut<'a>, K, V, Leaf>, Edge>>: Send, Option<&'a NodeRef<Owned, K, V, LeafOrInternal>>: Send,



impl<'a, K, V> Send for gstd::prelude::collections::btree_map::Iter<'a, K, V>
where LazyLeafRange<Immut<'a>, K, V>: Send,



impl<'a, K, V> Send for gstd::prelude::collections::hash_map::Iter<'a, K, V>
where RawIter<(K, V)>: Send, PhantomData<(&'a K, &'a V)>: Send,



impl<'a, K, V> Send for gstd::prelude::collections::btree_map::IterMut<'a, K, V>
where LazyLeafRange<ValMut<'a>, K, V>: Send, PhantomData<&'a mut (K, V)>: Send,



impl<'a, K, V> Send for gstd::prelude::collections::hash_map::Keys<'a, K, V>
where Iter<'a, K, V>: Send,



impl<'a, K, V> Send for gstd::prelude::collections::btree_map::Keys<'a, K, V>
where Iter<'a, K, V>: Send,



impl<'a, K, V> Send for gstd::prelude::collections::btree_map::Range<'a, K, V>
where LeafRange<Immut<'a>, K, V>: Send,



impl<'a, K, V> Send for RangeMut<'a, K, V>
where LeafRange<ValMut<'a>, K, V>: Send, PhantomData<&'a mut (K, V)>: Send,



impl<'a, K, V> Send for gstd::prelude::collections::hash_map::Values<'a, K, V>
where Iter<'a, K, V>: Send,



impl<'a, K, V> Send for gstd::prelude::collections::btree_map::Values<'a, K, V>
where Iter<'a, K, V>: Send,



impl<'a, K, V> Send for gstd::prelude::collections::hash_map::ValuesMut<'a, K, V>
where IterMut<'a, K, V>: Send,



impl<'a, K, V> Send for gstd::prelude::collections::btree_map::ValuesMut<'a, K, V>
where IterMut<'a, K, V>: Send,



impl<'a, K> Send for gstd::prelude::collections::btree_set::Cursor<'a, K>
where Cursor<'a, K, SetValZST>: Send,



impl<'a, K> Send for gstd::prelude::collections::hash_set::Iter<'a, K>
where Keys<'a, K, ()>: Send,



impl<'a, P> Send for MatchIndices<'a, P>
where MatchIndicesInternal<'a, P>: Send,



impl<'a, P> Send for Matches<'a, P>
where MatchesInternal<'a, P>: Send,



impl<'a, P> Send for RMatchIndices<'a, P>
where MatchIndicesInternal<'a, P>: Send,



impl<'a, P> Send for RMatches<'a, P>
where MatchesInternal<'a, P>: Send,



impl<'a, P> Send for gstd::prelude::str::RSplit<'a, P>
where SplitInternal<'a, P>: Send,



impl<'a, P> Send for gstd::prelude::str::RSplitN<'a, P>
where SplitNInternal<'a, P>: Send,



impl<'a, P> Send for RSplitTerminator<'a, P>
where SplitInternal<'a, P>: Send,



impl<'a, P> Send for gstd::prelude::str::Split<'a, P>
where SplitInternal<'a, P>: Send,



impl<'a, P> Send for gstd::prelude::str::SplitInclusive<'a, P>
where SplitInternal<'a, P>: Send,



impl<'a, P> Send for gstd::prelude::str::SplitN<'a, P>
where SplitNInternal<'a, P>: Send,



impl<'a, P> Send for SplitTerminator<'a, P>
where SplitInternal<'a, P>: Send,



impl<'a, T, A> Send for gstd::prelude::collections::btree_set::Difference<'a, T, A>
where DifferenceInner<'a, T, A>: Send,



impl<'a, T, A> Send for gstd::prelude::collections::binary_heap::Drain<'a, T, A>
where Drain<'a, T, A>: Send,



impl<'a, T, A> Send for DrainSorted<'a, T, A>
where &'a mut BinaryHeap<T, A>: Send,



impl<'a, T, A> Send for gstd::prelude::collections::btree_set::Entry<'a, T, A>
where OccupiedEntry<'a, T, A>: Send, VacantEntry<'a, T, A>: Send,



impl<'a, T, A> Send for gstd::prelude::collections::btree_set::Intersection<'a, T, A>
where IntersectionInner<'a, T, A>: Send,



impl<'a, T, A> Send for gstd::prelude::collections::btree_set::OccupiedEntry<'a, T, A>
where OccupiedEntry<'a, T, SetValZST, A>: Send,



impl<'a, T, A> Send for gstd::prelude::collections::binary_heap::PeekMut<'a, T, A>
where &'a mut BinaryHeap<T, A>: Send,



impl<'a, T, A> Send for gstd::prelude::vec::PeekMut<'a, T, A>
where &'a mut Vec<T, A>: Send,



impl<'a, T, A> Send for gstd::prelude::collections::btree_set::VacantEntry<'a, T, A>
where VacantEntry<'a, T, SetValZST, A>: Send,



impl<'a, T, F, A = Global> !Send for gstd::prelude::collections::linked_list::ExtractIf<'a, T, F, A>



impl<'a, T, F, A> Send for gstd::prelude::vec::ExtractIf<'a, T, F, A>
where &'a mut Vec<T, A>: Send, F: Send,



impl<'a, T, F, A> Send for gstd::prelude::collections::vec_deque::ExtractIf<'a, T, F, A>
where &'a mut VecDeque<T, A>: Send, F: Send,



impl<'a, T, P> Send for ChunkBy<'a, T, P>
where &'a [T]: Send, P: Send,



impl<'a, T, P> Send for ChunkByMut<'a, T, P>
where &'a mut [T]: Send, P: Send,



impl<'a, T, P> Send for gstd::prelude::slice::RSplit<'a, T, P>
where Split<'a, T, P>: Send,



impl<'a, T, P> Send for RSplitMut<'a, T, P>
where SplitMut<'a, T, P>: Send,



impl<'a, T, P> Send for gstd::prelude::slice::RSplitN<'a, T, P>
where GenericSplitN<RSplit<'a, T, P>>: Send,



impl<'a, T, P> Send for RSplitNMut<'a, T, P>
where GenericSplitN<RSplitMut<'a, T, P>>: Send,



impl<'a, T, P> Send for gstd::prelude::slice::Split<'a, T, P>
where &'a [T]: Send, P: Send,



impl<'a, T, P> Send for gstd::prelude::slice::SplitInclusive<'a, T, P>
where &'a [T]: Send, P: Send,



impl<'a, T, P> Send for SplitInclusiveMut<'a, T, P>
where &'a mut [T]: Send, P: Send,



impl<'a, T, P> Send for SplitMut<'a, T, P>
where &'a mut [T]: Send, P: Send,



impl<'a, T, P> Send for gstd::prelude::slice::SplitN<'a, T, P>
where GenericSplitN<Split<'a, T, P>>: Send,



impl<'a, T, P> Send for SplitNMut<'a, T, P>
where GenericSplitN<SplitMut<'a, T, P>>: Send,



impl<'a, T, R, F, A> Send for gstd::prelude::collections::btree_set::ExtractIf<'a, T, R, F, A>
where F: Send, ExtractIfInner<'a, T, SetValZST, R>: Send, A: Send,



impl<'a, T, S, A> Send for gstd::prelude::collections::hash_set::Difference<'a, T, S, A>
where Iter<'a, T>: Send, &'a HashSet<T, S, A>: Send,



impl<'a, T, S, A> Send for gstd::prelude::collections::hash_set::Entry<'a, T, S, A>
where OccupiedEntry<'a, T, S, A>: Send, VacantEntry<'a, T, S, A>: Send,



impl<'a, T, S, A> Send for gstd::prelude::collections::hash_set::Intersection<'a, T, S, A>
where Iter<'a, T>: Send, &'a HashSet<T, S, A>: Send,



impl<'a, T, S, A> Send for gstd::prelude::collections::hash_set::OccupiedEntry<'a, T, S, A>
where OccupiedEntry<'a, T, (), S, A>: Send,



impl<'a, T, S, A> Send for gstd::prelude::collections::hash_set::SymmetricDifference<'a, T, S, A>
where Chain<Difference<'a, T, S, A>, Difference<'a, T, S, A>>: Send,



impl<'a, T, S, A> Send for gstd::prelude::collections::hash_set::Union<'a, T, S, A>
where Chain<Iter<'a, T>, Difference<'a, T, S, A>>: Send,



impl<'a, T, S, A> Send for gstd::prelude::collections::hash_set::VacantEntry<'a, T, S, A>
where VacantEntry<'a, T, (), S, A>: Send,



impl<'a, T, const N: usize> Send for ArrayWindows<'a, T, N>
where &'a [T]: Send,



impl<'a, T> Send for Chunks<'a, T>
where &'a [T]: Send,



impl<'a, T> Send for ChunksExact<'a, T>
where &'a [T]: Send,



impl<'a, T> Send for gstd::prelude::collections::binary_heap::Iter<'a, T>
where Iter<'a, T>: Send,



impl<'a, T> Send for gstd::prelude::collections::vec_deque::Iter<'a, T>
where Iter<'a, T>: Send,



impl<'a, T> Send for gstd::prelude::collections::btree_set::Iter<'a, T>
where Keys<'a, T, SetValZST>: Send,



impl<'a, T> Send for gstd::prelude::result::Iter<'a, T>
where Option<&'a T>: Send,



impl<'a, T> Send for gstd::prelude::collections::vec_deque::IterMut<'a, T>
where IterMut<'a, T>: Send,



impl<'a, T> Send for gstd::prelude::result::IterMut<'a, T>



impl<'a, T> Send for MutexGuard<'a, T>
where &'a Mutex<T>: Send,



impl<'a, T> Send for MutexLockFuture<'a, T>
where &'a Mutex<T>: Send,



impl<'a, T> Send for RChunks<'a, T>
where &'a [T]: Send,



impl<'a, T> Send for RChunksExact<'a, T>
where &'a [T]: Send,



impl<'a, T> Send for gstd::prelude::collections::btree_set::Range<'a, T>
where Range<'a, T, SetValZST>: Send,



impl<'a, T> Send for RwLockReadFuture<'a, T>
where &'a RwLock<T>: Send,



impl<'a, T> Send for RwLockReadGuard<'a, T>
where &'a RwLock<T>: Send,



impl<'a, T> Send for RwLockWriteFuture<'a, T>
where &'a RwLock<T>: Send,



impl<'a, T> Send for RwLockWriteGuard<'a, T>
where &'a RwLock<T>: Send,



impl<'a, T> Send for gstd::prelude::collections::btree_set::SymmetricDifference<'a, T>
where MergeIterInner<Iter<'a, T>>: Send,



impl<'a, T> Send for gstd::prelude::collections::btree_set::Union<'a, T>
where MergeIterInner<Iter<'a, T>>: Send,



impl<'a, T> Send for Windows<'a, T>
where &'a [T]: Send,



impl<'a, const N: usize> Send for CharArraySearcher<'a, N>
where <MultiCharEqPattern<[char; N]> as Pattern>::Searcher<'a>: Send,



impl<'a> !Send for Context<'a>



impl<'a> !Send for ContextBuilder<'a>



impl<'a> !Send for Formatter<'a>



impl<'a> !Send for PanicInfo<'a>



impl<'a> !Send for PanicMessage<'a>



impl<'a> !Send for VaList<'a>



impl<'a> Send for gstd::prelude::str::Bytes<'a>



impl<'a> Send for CharIndices<'a>



impl<'a> Send for CharSearcher<'a>



impl<'a> Send for Chars<'a>



impl<'a> Send for EncodeUtf16<'a>



impl<'a> Send for EscapeAscii<'a>



impl<'a> Send for gstd::prelude::str::EscapeDebug<'a>



impl<'a> Send for gstd::prelude::str::EscapeDefault<'a>



impl<'a> Send for gstd::prelude::str::EscapeUnicode<'a>



impl<'a> Send for Lines<'a>



impl<'a> Send for LinesAny<'a>



impl<'a> Send for PhantomContravariantLifetime<'a>



impl<'a> Send for PhantomCovariantLifetime<'a>



impl<'a> Send for PhantomInvariantLifetime<'a>



impl<'a> Send for gstd::prelude::str::SplitAsciiWhitespace<'a>



impl<'a> Send for gstd::prelude::slice::SplitAsciiWhitespace<'a>



impl<'a> Send for SplitWhitespace<'a>



impl<'a> Send for Utf8Chunk<'a>



impl<'a> Send for Utf8Chunks<'a>



impl<'a> Send for Utf8Pattern<'a>



impl<'b, T> !Send for Ref<'b, T>



impl<'b, T> !Send for RefMut<'b, T>



impl<A, B> Send for Chain<A, B>
where Option<A>: Send, Option<B>: Send,



impl<A, B> Send for Zip<A, B>
where A: Send, B: Send,



impl<A> Send for gstd::prelude::option::IntoIter<A>
where Item<A>: Send,



impl<A> Send for OptionFlatten<A>
where Option<A>: Send,



impl<A> Send for Repeat<A>
where A: Send,



impl<A> Send for RepeatN<A>
where Option<RepeatNInner<A>>: Send,



impl<B, C> Send for ControlFlow<B, C>
where C: Send, B: Send,



impl<F> Send for gstd::prelude::fmt::FromFn<F>
where F: Send,



impl<F> Send for gstd::prelude::iter::FromFn<F>
where F: Send,



impl<F> Send for OnceWith<F>
where Option<F>: Send,



impl<F> Send for PollFn<F>
where F: Send,



impl<F> Send for RepeatWith<F>
where F: Send,



impl<G> Send for FromCoroutine<G>
where G: Send,



impl<H> Send for BuildHasherDefault<H>
where PhantomData<fn() -> H>: Send,



impl<I, F, const N: usize> Send for MapWindows<I, F, N>
where F: Send, MapWindowsInner<I, N>: Send,



impl<I, F> Send for FilterMap<I, F>
where I: Send, F: Send,



impl<I, F> Send for Inspect<I, F>
where I: Send, F: Send,



impl<I, F> Send for Map<I, F>
where I: Send, F: Send,



impl<I, G> Send for IntersperseWith<I, G>
where G: Send, Option<<I as Iterator>::Item>: Send, I: Send,



impl<I, P> Send for Filter<I, P>
where I: Send, P: Send,



impl<I, P> Send for MapWhile<I, P>
where I: Send, P: Send,



impl<I, P> Send for SkipWhile<I, P>
where I: Send, P: Send,



impl<I, P> Send for TakeWhile<I, P>
where I: Send, P: Send,



impl<I, St, F> Send for Scan<I, St, F>
where I: Send, F: Send, St: Send,



impl<I, U, F> Send for FlatMap<I, U, F>
where FlattenCompat<Map<I, F>, <U as IntoIterator>::IntoIter>: Send,



impl<I, const N: usize> Send for ArrayChunks<I, N>
where I: Send, Option<IntoIter<<I as Iterator>::Item, N>>: Send,



impl<I> Send for Cloned<I>
where I: Send,



impl<I> Send for Copied<I>
where I: Send,



impl<I> Send for Cycle<I>
where I: Send,



impl<I> Send for DecodeUtf16<I>
where I: Send,



impl<I> Send for Enumerate<I>
where I: Send,



impl<I> Send for Flatten<I>
where FlattenCompat<I, <<I as Iterator>::Item as IntoIterator>::IntoIter>: Send,



impl<I> Send for Fuse<I>
where Option<I>: Send,



impl<I> Send for Intersperse<I>
where <I as Iterator>::Item: Sized + Send, Option<<I as Iterator>::Item>: Send, I: Send,



impl<I> Send for Peekable<I>
where I: Send, Option<Option<<I as Iterator>::Item>>: Send,



impl<I> Send for Skip<I>
where I: Send,



impl<I> Send for StepBy<I>
where I: Send,



impl<I> Send for Take<I>
where I: Send,



impl<Idx> Send for gstd::prelude::ops::Range<Idx>
where Idx: Send,



impl<Idx> Send for RangeFrom<Idx>
where Idx: Send,



impl<Idx> Send for RangeInclusive<Idx>
where Idx: Send,



impl<Idx> Send for RangeTo<Idx>
where Idx: Send,



impl<Idx> Send for RangeToInclusive<Idx>
where Idx: Send,



impl<K, A> Send for gstd::prelude::collections::hash_set::IntoIter<K, A>
where IntoIter<K, (), A>: Send,



impl<K, V, A> Send for BTreeMap<K, V, A>
where Option<NodeRef<Owned, K, V, LeafOrInternal>>: Send, ManuallyDrop<A>: Send, PhantomData<Box<(K, V), A>>: Send,



impl<K, V, A> Send for gstd::prelude::collections::btree_map::IntoIter<K, V, A>
where LazyLeafRange<Dying, K, V>: Send, A: Send,



impl<K, V, A> Send for gstd::prelude::collections::hash_map::IntoIter<K, V, A>
where RawIntoIter<(K, V), A>: Send,



impl<K, V, A> Send for gstd::prelude::collections::hash_map::IntoKeys<K, V, A>
where IntoIter<K, V, A>: Send,



impl<K, V, A> Send for gstd::prelude::collections::btree_map::IntoKeys<K, V, A>
where IntoIter<K, V, A>: Send,



impl<K, V, A> Send for gstd::prelude::collections::hash_map::IntoValues<K, V, A>
where IntoIter<K, V, A>: Send,



impl<K, V, A> Send for gstd::prelude::collections::btree_map::IntoValues<K, V, A>
where IntoIter<K, V, A>: Send,



impl<K, V, S, A> Send for HashMap<K, V, S, A>
where S: Send, RawTable<(K, V), A>: Send,



impl<P> Send for MaybeDangling<P>
where P: Send + ?Sized,



impl<Ptr> Send for Pin<Ptr>
where Ptr: Send,



impl<T, A> Send for BTreeSet<T, A>
where BTreeMap<T, SetValZST, A>: Send,



impl<T, A> Send for BinaryHeap<T, A>
where Vec<T, A>: Send,



impl<T, A> Send for gstd::prelude::Box<T, A>
where Unique<T>: Send, A: Send, T: ?Sized,



impl<T, A> Send for gstd::prelude::collections::binary_heap::IntoIter<T, A>
where IntoIter<T, A>: Send,



impl<T, A> Send for gstd::prelude::collections::btree_set::IntoIter<T, A>
where IntoIter<T, SetValZST, A>: Send,



impl<T, A> Send for gstd::prelude::collections::linked_list::IntoIter<T, A>
where LinkedList<T, A>: Send,



impl<T, A> Send for gstd::prelude::collections::vec_deque::IntoIter<T, A>
where VecDeque<T, A>: Send,



impl<T, A> Send for IntoIterSorted<T, A>
where BinaryHeap<T, A>: Send,



impl<T, A> Send for Vec<T, A>
where RawVec<T, A>: Send,



impl<T, A> Send for VecDeque<T, A>
where RawVec<T, A>: Send,



impl<T, E> Send for Result<T, E>
where T: Send, E: Send,



impl<T, F> Send for DropGuard<T, F>



impl<T, F> Send for LazyCell<T, F>
where UnsafeCell<State<T, F>>: Send,



impl<T, F> Send for Successors<T, F>
where Option<T>: Send, F: Send,



impl<T, S, A> Send for HashSet<T, S, A>
where HashMap<T, (), S, A>: Send,



impl<T, const N: usize, A> Send for BoxedArrayIntoIter<T, N, A>
where IntoIter<T, A>: Send,



impl<T, const N: usize> Send for gstd::prelude::array::IntoIter<T, N>
where ManuallyDrop<PolymorphicIter<[MaybeUninit<T>; N]>>: Send,



impl<T> Send for AssertUnwindSafe<T>
where T: Send,



impl<T> Send for Bound<T>
where T: Send,



impl<T> Send for CodecCreateProgramFuture<T>
where PhantomData<T>: Send,



impl<T> Send for CodecMessageFuture<T>
where PhantomData<T>: Send,



impl<T> Send for Complex<T>
where T: Send,



impl<T> Send for CovariantUnsafeCell<T>
where UnsafeCell<T>: Send, T: ?Sized,



impl<T> Send for Discriminant<T>



impl<T> Send for Empty<T>
where PhantomData<fn() -> T>: Send,



impl<T> Send for gstd::prelude::result::IntoIter<T>
where Option<T>: Send,



impl<T> Send for ManuallyDrop<T>
where T: Send + ?Sized,



impl<T> Send for MaybeUninit<T>
where ManuallyDrop<T>: Send,



impl<T> Send for Mutex<T>
where UnsafeCell<T>: Send,



impl<T> Send for NumBuffer<T>
where <T as NumBufferTrait>::Buf: Send, PhantomData<T>: Send,



impl<T> Send for Once<T>
where IntoIter<T>: Send,



impl<T> Send for OnceCell<T>
where UnsafeCell<Option<T>>: Send,



impl<T> Send for Option<T>
where T: Send,



impl<T> Send for Pending<T>
where PhantomData<fn() -> T>: Send,



impl<T> Send for PhantomContravariant<T>
where PhantomData<fn(T)>: Send, T: ?Sized,



impl<T> Send for PhantomCovariant<T>
where PhantomData<fn() -> T>: Send, T: ?Sized,



impl<T> Send for PhantomData<T>
where T: ?Sized,



impl<T> Send for PhantomInvariant<T>
where PhantomData<fn(T) -> T>: Send, T: ?Sized,



impl<T> Send for Poll<T>
where T: Send,



impl<T> Send for Ready<T>
where Option<T>: Send,



impl<T> Send for Rev<T>
where T: Send,



impl<T> Send for Reverse<T>
where T: Send,



impl<T> Send for RwLock<T>
where UnsafeCell<T>: Send,



impl<T> Send for Saturating<T>
where T: Send,



impl<T> Send for SyncUnsafeCell<T>
where UnsafeCell<T>: Send, T: ?Sized,



impl<T> Send for TraitImpl<T>
where DynMetadata<T>: Send, T: ?Sized,



impl<T> Send for UnsafeCell<T>
where T: Send + ?Sized,



impl<T> Send for UnsafePinned<T>
where UnsafeCell<T>: Send, T: ?Sized,



impl<T> Send for Wrapping<T>
where T: Send,



impl<T> Send for Yeet<T>
where T: Send,



impl<Y, R> Send for CoroutineState<Y, R>
where Y: Send, R: Send,