Struct gstd::sync::RwLockReadFuture
source · pub struct RwLockReadFuture<'a, T> { /* private fields */ }Expand description
The future returned by the read method.
The output of the future is the RwLockReadGuard that can be obtained by
using await syntax.
Examples
The following example explicitly annotates variable types for demonstration purposes only. Usually, annotating types is unnecessary since they can be inferred automatically.
use gstd::sync::{RwLock, RwLockReadFuture, RwLockReadGuard};
#[gstd::async_main]
async fn main() {
let rwlock: RwLock<i32> = RwLock::new(42);
let future: RwLockReadFuture<i32> = rwlock.read();
let guard: RwLockReadGuard<i32> = future.await;
let value: i32 = *guard;
assert_eq!(value, 42);
}Trait Implementations
sourceimpl<'a, T> Future for RwLockReadFuture<'a, T>
impl<'a, T> Future for RwLockReadFuture<'a, T>