pub unsafe auto trait Send { }Expand description
Types that can be transferred across thread boundaries.
This trait is automatically implemented when the compiler determines it’s appropriate.
An example of a non-Send type is the reference-counting pointer
rc::Rc. If two threads attempt to clone Rcs that point to the same
reference-counted value, they might try to update the reference count at the
same time, which is undefined behavior because Rc doesn’t use atomic
operations. Its cousin sync::Arc does use atomic operations (incurring
some overhead) and thus is Send.
See the Nomicon and the Sync trait for more details.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl !Send for Arguments<'_>
impl !Send for LocalWaker
impl Send for AtomicWaker
impl Send for gstd::prelude::ffi::c_str::Bytes<'_>
impl Send for gstd::prelude::string::Drain<'_>
impl Send for Location<'_>
impl Send for TypeId
impl Send for Waker
impl<'a, 'b, K, Q, V, S, A> Send for OccupiedEntryRef<'a, 'b, K, Q, V, S, A>
impl<'a, T, const CAP: usize> Send for arrayvec::arrayvec::Drain<'a, T, CAP>where
T: Send,
impl<'a, T> Send for smallvec::Drain<'a, T>
impl<'a> Send for IoSlice<'a>
impl<'a> Send for IoSliceMut<'a>
impl<A> Send for SmallVec<A>
impl<Dyn> Send for DynMetadata<Dyn>where
Dyn: ?Sized,
impl<Fut> Send for FuturesUnordered<Fut>where
Fut: Send,
impl<Fut> Send for futures_util::stream::futures_unordered::iter::IntoIter<Fut>
impl<Fut> Send for IterPinMut<'_, Fut>where
Fut: Send,
impl<Fut> Send for IterPinRef<'_, Fut>where
Fut: Send,
impl<K, V, S, A> Send for gstd::prelude::collections::hash_map::OccupiedEntry<'_, K, V, S, A>
impl<K, V, S, A> Send for RawOccupiedEntryMut<'_, K, V, S, A>
impl<K, V> Send for gstd::prelude::collections::hash_map::IterMut<'_, K, V>
impl<T, A> !Send for Rc<T, A>
impl<T, A> !Send for UniqueRc<T, A>
impl<T, A> !Send for gstd::prelude::rc::Weak<T, A>
impl<T, A> Send for Arc<T, A>
impl<T, A> Send for allocator_api2::stable::boxed::Box<T, A>
impl<T, A> Send for gstd::prelude::collections::linked_list::Cursor<'_, T, A>
impl<T, A> Send for gstd::prelude::collections::linked_list::CursorMut<'_, T, A>
impl<T, A> Send for gstd::prelude::collections::vec_deque::Drain<'_, T, A>
impl<T, A> Send for gstd::prelude::vec::Drain<'_, T, A>
impl<T, A> Send for allocator_api2::stable::vec::drain::Drain<'_, T, A>
impl<T, A> Send for gstd::prelude::vec::IntoIter<T, A>
impl<T, A> Send for allocator_api2::stable::vec::into_iter::IntoIter<T, A>
impl<T, A> Send for LinkedList<T, A>
impl<T, A> Send for hashbrown::table::OccupiedEntry<'_, T, A>
impl<T, A> Send for UniqueArc<T, A>
impl<T, A> Send for alloc::sync::Weak<T, A>
impl<T, N> Send for GenericArray<T, N>where
T: Send,
N: ArrayLength<T>,
impl<T> !Send for *const Twhere
T: ?Sized,
impl<T> !Send for *mut Twhere
T: ?Sized,
impl<T> !Send for NonNull<T>where
T: ?Sized,
NonNull pointers are not Send because the data they reference may be aliased.
impl<T> Send for &T
impl<T> Send for Atomic<T>where
T: AtomicPrimitive,
impl<T> Send for Cell<T>
impl<T> Send for ChunksExactMut<'_, T>where
T: Send,
impl<T> Send for ChunksMut<'_, T>where
T: Send,
impl<T> Send for FutureObj<'_, T>
impl<T> Send for gstd::prelude::slice::Iter<'_, T>where
T: Sync,
impl<T> Send for gstd::prelude::collections::linked_list::Iter<'_, T>where
T: Sync,
impl<T> Send for gstd::prelude::slice::IterMut<'_, T>where
T: Send,
impl<T> Send for gstd::prelude::collections::linked_list::IterMut<'_, T>where
T: Send,
impl<T> Send for NonZero<T>where
T: ZeroablePrimitive + Send,
impl<T> Send for RChunksExactMut<'_, T>where
T: Send,
impl<T> Send for RChunksMut<'_, T>where
T: Send,
impl<T> Send for RefCell<T>
impl<T> Send for ThinBox<T>
ThinBox<T> is Send if T is Send because the data is owned.