ActorId

Struct ActorId 

pub struct ActorId(/* private fields */);
Program (actor) identifier.

Gear allows user and program interactions via messages. Source and target program as well as user are represented by 256-bit identifier ActorId struct. The source ActorId for a message being processed can be obtained using gstd::msg::source() function. Also, each send function has a target ActorId as one of the arguments.

NOTE: Implementation of From<u64> places bytes from idx=12 for Eth compatibility.

Implementations

Source

impl ActorId

pub const fn new(array: [u8; 32]) -> ActorId

Creates a new ActorId from a 32-byte array.

Source

impl ActorId

pub const fn zero() -> ActorId

Creates a new zero ActorId.

pub fn is_zero(&self) -> bool

Checks whether ActorId is zero.

Source

impl ActorId

pub fn into_bytes(self) -> [u8; 32]

Returns ActorIdas bytes array.

Source

impl ActorId

pub fn to_ss58check(&self) -> Result<Ss58Address, ConversionError>

Returns the ss58-check address with default ss58 version.

pub fn to_ss58check_with_version( &self, version: u16, ) -> Result<Ss58Address, ConversionError>

Returns the ss58-check address with given ss58 version.

pub fn to_address_lossy(&self) -> H160

Returns H160 with possible loss of the first 12 bytes.