Utility functions.
Structs
- Meta
Type - A metatype abstraction.
Functions
- to_
hex_ registry - Generate a registry from given meta types and encode it to hex.
- to_
leak_ ptr - Convert a given vector to a raw pointer and prevent its deallocating.
- to_
wasm_ ptr - Convert a given reference to a raw pointer.